
"""
Handle /etc/network/interfaces.d/blah management
"""

import os
from socle.menu import choice, form
from socle.helpers import pick_network_interface
from socle.atomic import AtomicWrite

def ask_wireless_settings(interface):
    return form(
		(("Network name", "bootcamp"), ("Passphrase", "salakala")),
        "Reconfigure " + interface,
        "Enter your wireless network details, leave password blank for open network")

def reconfigure_interface_with_static_address(interface, wpa_essid, wpa_psk):
    FIELDS = (
        ("IPv4 address", "192.168.76.2"),
        ("IPv4 netmask", "255.255.255.0"),
        ("Gateway", "192.168.76.1"),
        ("Primary DNS", "8.8.8.8"),
        ("Secondary DNS", "8.8.4.4"),
    )
    
    address, netmask, gateway, primary, secondary = form(
        FIELDS,
        "Reconfigure IPv4 for " + interface,
        "Enter IPv4 configuration for network interface " + interface)

    with AtomicWrite("/etc/network/interfaces.d/" + interface) as fh:
        fh.write("iface %s inet static\n" % interface)
        fh.write("address %s\n" % address)
        fh.write("netmask %s\n" % address)
        fh.write("gateway %s\n" % gateway)
        if primary or secondary:
            fh.write("dns-nameservers")
            if primary:
                fh.write(" ")
                fh.write(primary)
            if secondary:
                fh.write(" ")
                fh.write(secondary)
            fh.write("\n")

        if wpa_psk:
            if wpa_essid:
                fh.write("wpa-ssid '%s'\n" % wpa_essid)
                fh.write("wpa-psk '%s'\n" % wpa_psk)
            else:
                fh.write("wireless-ssid '%s'\n" % wpa_essid)

@pick_network_interface
def reconfigure_network_interface(interface):
    is_wireless = os.path.exists(os.path.join("/sys/class/net", interface, "phy80211"))
    
    CHOICES = (
        ("Static IP address", 1),
        ("Dynamic IP address", 2),
    )
    
    if is_wireless:
        CHOICES += ("Access point", 3),
        
    action = choice(CHOICES,
        "Reconfigure " + interface,
        "How do you want to reconfigure " + interface)
    
    if is_wireless:
        wpa_essid, wpa_psk = ask_wireless_settings(interface)
    else:
        wpa_essid, wpa_psk = None, None
        
    if action == 1:
        reconfigure_interface_with_static_address(interface, wpa_essid, wpa_psk)
    elif action == 2:
        with AtomicWrite("/etc/network/interfaces.d/" + interface) as fh:
            fh.write("# Generated by socle")
            fh.write("iface %s inet dhcp\n" % interface)
            if wpa_psk:
                if wpa_essid:
                    fh.write("wpa-ssid '%s'\n" % wpa_essid)
                    fh.write("wpa-psk '%s'\n" % wpa_psk)
                else:
                    fh.write("wireless-ssid '%s'\n" % wpa_eesid)

MENU_ENTRIES = (
    ("Reconfigure network interfaces", reconfigure_network_interface),
)
